@@ -2,7 +2,7 @@
 #
 # Encoding of Arabic: ArabTeX Notation by Klaus Lagally, ZDMG #################################
 
-# $Id: ZDMG.pm 143 2006-11-15 01:16:57Z smrz $
+# $Id: ZDMG.pm 338 2007-06-07 01:30:40Z smrz $
 
 package Encode::Arabic::ArabTeX::ZDMG;
 
@@ -13,7 +13,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = do { q $Revision: 143 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
+our $VERSION = do { q $Revision: 338 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
 
 
 use Encode::Arabic::ArabTeX ();
@@ -449,7 +449,7 @@ Encode::Arabic::ArabTeX::ZDMG - ZDMG phonetic transcription of Arabic using the
 
 =head1 REVISION
 
-    $Revision: 143 $        $Date: 2006-11-15 02:16:57 +0100 (Wed, 15 Nov 2006) $
+    $Revision: 338 $        $Date: 2007-06-07 03:30:40 +0200 (Thu, 07 Jun 2007) $
 
 
 =head1 SYNOPSIS
@@ -485,15 +485,17 @@ inherits. The transformation rules are, however, quite different ;)
 =head1 SEE ALSO
 
 L<Encode::Arabic::ArabTeX|Encode::Arabic::ArabTeX>,
-L<Encode::Arabic|Encode::Arabic>,
-L<Encode::Mapper|Encode::Mapper>,
-L<Encode::Encoding|Encode::Encoding>,
-L<Encode|Encode>
+L<Encode::Arabic|Encode::Arabic>, L<Encode::Mapper|Encode::Mapper>,
+L<Encode::Encoding|Encode::Encoding>, L<Encode|Encode>
 
 ArabTeX system      L<ftp://ftp.informatik.uni-stuttgart.de/pub/arabtex/arabtex.htm>
 
 Klaus Lagally       L<http://www.informatik.uni-stuttgart.de/ifi/bs/people/lagall_e.htm>
 
+ArabTeX extensions  L<http://sourceforge.net/projects/encode-arabic/>
+
+ArabXeTeX           L<http://tug.ctan.org/info/?id=arabxetex>
+
 Encode Arabic: Exercise in Functional Parsing
     L<http://ufal.mff.cuni.cz/padt/online/2006/06/encode-arabic.html>
 
@@ -509,7 +511,7 @@ Perl is also designed to make the easy jobs not that easy ;)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2006 by Otakar Smrz
+Copyright 2003-2007 by Otakar Smrz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
